% Basic integrate-and-fire neuron 
% R Rao 1999  (adapted for 590rr)

clear
% input current
I_1 = 7; % nA  1
I_2 = 7;

I_1_start       = 10;
I_2_start       = 60;

I_1_duration    = 2;
I_2_duration    = 2;

% capacitance and leak resistance
C = 1; % nF  1
R = 20; % M ohms  20

% I & F implementation dV/dt = - V/RC + I/C
% Using h = 1 ms step size, Euler method

V = 0;
tstop = 200;
abs_ref = 15; % absolute refractory period 15
ref = 0; % absolute refractory period counter
V_trace = []; % voltage trace for plotting
V_th = 10; % spike threshold  10
V_spike = 50;

time = 1:tstop;

input = I_1*(time>=I_1_start).*(time<(I_1_start+I_1_duration)) + I_2*(time>=I_2_start).*(time<(I_2_start+I_2_duration));

for t = 1:tstop
  
   if ~ref
     V = V - (V/(R*C)) + (input(t)/C);
   else
     ref = ref - 1;
     V = 0.2*V_th; % reset voltage
   end
   
   if (V > V_th)
     V = V_spike;  % emit spike
     ref = abs_ref; % set refractory counter
   end

   V_trace = [V_trace V];

end

figure(2);
j=subplot(211); set(j,'FontSize',20);
plot(V_trace, 'LineWidth', 3);
axis([0 tstop 0 V_spike]);
ylabel('Voltage', 'FontSize', 20);
  
j=subplot(212); set(j,'FontSize',20);
plot(input, 'LineWidth', 3);
axis([0 tstop 0 10]);
xlabel('Time (ms)', 'FontSize', 20);
ylabel('Input Current (nA)', 'FontSize', 20);
